{
  inputs = {
    nixpkgs.url = "github:NixOS/nixpkgs/nixos-23.11";
    devenv.url = "github:cachix/devenv";
  };

  nixConfig = {
    extra-trusted-public-keys = "devenv.cachix.org-1:w1cLUi8dv3hnoSPGAuibQv+f9TZLr6cv/Hm9XgU50cw=";
    extra-substituters = "https://devenv.cachix.org";
  };

  outputs = { self, nixpkgs, devenv, ... } @ inputs:
    let
      pkgs = nixpkgs.legacyPackages."x86_64-linux";
    in
    {
      packages.x86_64-linux.devenv-up = self.devShell.x86_64-linux.config.procfileScript;
      devShell.x86_64-linux = devenv.lib.mkShell {
        inherit inputs pkgs;
        modules = [
          ({ pkgs, config, ... }: {
            # This is your devenv configuration (devenv.nix)
            packages = [
              pkgs.bun
              pkgs.nodejs_21
            ];

            dotenv.enable = true;
            dotenv.disableHint = true;

            services.postgres = {
              enable = true;
              package = pkgs.postgresql_15;
              initialDatabases = [{ name = "hclotting"; }];
              port = 5432;
              listen_addresses = "127.0.0.255";
            };
          })
        ];
      };
    };
}